pub enum WebServerDestination {
Addr(SocketAddr),
Url(Url),
}Available on crate feature
netcode only.Expand description
Represents a WebTransport server destination.
When setting up WebTransport servers and clients, this destination must be used.
WebTransportClientConfig::server_dest: Set the destination here. This tells the client where to connect.ServerSetupConfig::server_addresses: Store the destination as aSocketAddrin the server addresses for the WebTransport server. This is used to validate connect tokens.ClientAuthentication: Use the destination inClientAuthentication::Unsecure::server_addressor inConnectToken::generate()for secure auth. The server address is used internally byrenet2to coordinate packet sending and receiving.
The conversion SocketAddr::from(WebServerDestination::Url) is not reversible. The conversion involves
hashing the URL and pasting it into the socket address bytes (28 bytes total).
Variants
Addr(SocketAddr)
Url(Url)
The server destination as a URL.
This URL must include the port number explicitly.